@@ -21,7 +21,7 @@
 
 LinMatrixL <- function(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,poped.db){
   
-  if((poped.db$NumRanEff==0)){
+  if((poped.db$parameters$NumRanEff==0)){
     y=0
   } else {
     returnArgs <- gradff(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,poped.db) 
