@@ -51,17 +51,17 @@ RS_opt <- function(poped.db,
                    fmf=0,
                    dmf=0,
                    trflag = TRUE,
-                   opt_xt=poped.db$optsw[2],
-                   opt_a=poped.db$optsw[4],
-                   opt_x=poped.db$optsw[3],
-                   cfaxt=poped.db$cfaxt, 
-                   cfaa=poped.db$cfaa,
-                   rsit=poped.db$rsit,
-                   rsit_output=poped.db$rsit_output,
-                   fim.calc.type=poped.db$iFIMCalculationType,
-                   #ofv_calc_type=poped.db$ofv_calc_type,
-                   #ds_index = poped.db$ds_index
-                   approx_type=poped.db$iApproximationMethod,
+                   opt_xt=poped.db$settings$optsw[2],
+                   opt_a=poped.db$settings$optsw[4],
+                   opt_x=poped.db$settings$optsw[3],
+                   cfaxt=poped.db$settings$cfaxt, 
+                   cfaa=poped.db$settings$cfaa,
+                   rsit=poped.db$settings$rsit,
+                   rsit_output=poped.db$settings$rsit_output,
+                   fim.calc.type=poped.db$settings$iFIMCalculationType,
+                   #ofv_calc_type=poped.db$settings$ofv_calc_type,
+                   #ds_index = poped.db$parameters$ds_index
+                   approx_type=poped.db$settings$iApproximationMethod,
                    iter=1,
                    ...){
   # change so that only one output file and one summary file
@@ -73,20 +73,20 @@ RS_opt <- function(poped.db,
   
   # Only get inputs that are needed, not double inputs
   # needed inputs to function: get first then run function
-  # poped.db$cfaxt     0.001
-  # poped.db$m
-  # poped.db$maxni
-  # poped.db$optsw
-  # poped.db$cfaa
-  # poped.db$na
-  # poped.db$covd
-  # poped.db$covdocc
-  # poped.db$docc
-  # poped.db$groupsize
-  # poped.db$sigma
-  # poped.db$bShowGraphs
-  # poped.db$maxrsnullit # when to make the search area smaller
-  # poped.db$strIterationFileName iteration file if not empty string
+  # poped.db$settings$cfaxt     0.001
+  # poped.db$design$m
+  # max(poped.db$design_space$maxni)
+  # poped.db$settings$optsw
+  # poped.db$settings$cfaa
+  # size(poped.db$design$a,2)
+  # poped.db$parameters$covd
+  # poped.db$parameters$covdocc
+  # poped.db$parameters$docc
+  # poped.db$design$groupsize
+  # poped.db$parameters$sigma
+  # poped.db$settings$bShowGraphs
+  # poped.db$settings$maxrsnullit # when to make the search area smaller
+  # poped.db$settings$strIterationFileName iteration file if not empty string
   
   ## update poped.db with options supplied in function
   called_args <- match.call()
@@ -127,34 +127,34 @@ RS_opt <- function(poped.db,
   
   # ----------------- initialization of model parameters
   bpop=bpopdescr[,2,drop=F]
-  d=getfulld(ddescr[,2,drop=F],poped.db$covd)
-  docc_full = getfulld(poped.db$docc[,2,drop=F],poped.db$covdocc)
+  d=getfulld(ddescr[,2,drop=F],poped.db$parameters$covd)
+  docc_full = getfulld(poped.db$parameters$docc[,2,drop=F],poped.db$parameters$covdocc)
   
   if((fmf==0) ){
     #     tot.time <- 0
     #     n <- 100
     #     for(i in 1:n){
-    #       times <- system.time(mftot(model_switch,poped.db$groupsize,ni,xt,x,a,bpop,d,poped.db$sigma,docc_full,poped.db))
+    #       times <- system.time(mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
     #       tot.time <- tot.time + times
     #     }
     #     avg.time <- tot.time/n
     #     avg.time
     #     
-    #     system.time(for(i in 1:100) mftot(model_switch,poped.db$groupsize,ni,xt,x,a,bpop,d,poped.db$sigma,docc_full,poped.db))
-    #     system.time(mftot(model_switch,poped.db$groupsize,ni,xt,x,a,bpop,d,poped.db$sigma,docc_full,poped.db))
+    #     system.time(for(i in 1:100) mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
+    #     system.time(mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db))
     #     
     #     system.time(for(i in 1:100){
     #     evaluate.fim(poped.db,
     #                  bpop.val=bpop,
     #                  d_full=d,
     #                  docc_full=docc_full,
-    #                  sigma_full=poped.db$sigma,
+    #                  sigma_full=poped.db$parameters$sigma,
     #                  model_switch=model_switch,
     #                  ni=ni,
     #                  xt=xt,
     #                  x=x,
     #                  a=a,
-    #                  groupsize=poped.db$groupsize,
+    #                  groupsize=poped.db$design$groupsize,
     #                  ...)
     #     }    
     #     )
@@ -163,17 +163,17 @@ RS_opt <- function(poped.db,
                         bpop.val=bpop,
                         d_full=d,
                         docc_full=docc_full,
-                        sigma_full=poped.db$sigma,
+                        sigma_full=poped.db$parameters$sigma,
                         model_switch=model_switch,
                         ni=ni,
                         xt=xt,
                         x=x,
                         a=a,
-                        groupsize=poped.db$groupsize,
+                        groupsize=poped.db$design$groupsize,
                         fim.calc.type=fim.calc.type,
                         ...)
     
-    #     returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt,x,a,bpop,d,poped.db$sigma,docc_full,poped.db) 
+    #     returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt,x,a,bpop,d,poped.db$parameters$sigma,docc_full,poped.db) 
     #     fmf <- returnArgs[[1]]
     #     poped.db <- returnArgs[[2]]
   }
@@ -195,16 +195,16 @@ RS_opt <- function(poped.db,
                      opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,
                      opt_inds=F,opt_samps=F,
                      fmf=fmf_init,dmf=dmf_init,
-                     bpop=bpopdescr,d=ddescr,docc=poped.db$docc,sigma=poped.db$sigma)
+                     bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma)
     param_vars_init=diag_matlab(inv(fmf))
-    returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$docc,sigma=poped.db$sigma,poped.db) 
+    returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,poped.db) 
     params_init <- returnArgs[[1]]
     param_cvs_init <- returnArgs[[2]]
   }
   
-  # if((poped.db$bShowGraphs && trflag)){
+  # if((poped.db$settings$bShowGraphs && trflag)){
   #     figure(1)
-  #     if((poped.db$Engine$Type==1)){
+  #     if((poped.db$settings$Engine$Type==1)){
   #         set(1,'Name','Random Search')
   #     }
   # }
@@ -218,8 +218,8 @@ RS_opt <- function(poped.db,
   aopt=a
   
   # ----------------- RS variables initialization
-  dxt=(maxxt-minxt)/poped.db$rslxt
-  da=(maxa-mina)/poped.db$rsla
+  dxt=(maxxt-minxt)/poped.db$settings$rslxt
+  da=(maxa-mina)/poped.db$settings$rsla
   xtoptn=xtopt
   xoptn=xopt
   aoptn=aopt
@@ -238,15 +238,15 @@ RS_opt <- function(poped.db,
     Dtrace(fn,0,ni,xtopt,xopt,aopt,matrix(0,0,0),matrix(0,0,0),dmf,matrix(0,0,0),matrix(0,0,0),matrix(0,0,0),itvector,dmfvector,poped.db)
   }
   
-  if((poped.db$parallelSettings$bParallelRS)){
+  if((poped.db$settings$parallel$bParallelRS)){
     
     # Generate the input designs
     
     designsin = cell(1,0)
     for(it in 1:rsit){
       if((optxt==TRUE)){
-        if((poped.db$bUseGrouped_xt)){
-          xtoptn=grouped_rand(poped.db$G,xtopt,dxt,ff,axt)
+        if((poped.db$design_space$bUseGrouped_xt)){
+          xtoptn=grouped_rand(poped.db$design_space$G_xt,xtopt,dxt,ff,axt)
         } else {
           xtoptn=xtopt+dxt/ff*randn(m,maxni)*(axt>0)
         }
@@ -254,18 +254,18 @@ RS_opt <- function(poped.db,
         xtoptn=xtoptn+((xtoptn<minxt)*(minxt-xtoptn))
       }
       if((optx==TRUE)){
-        xoptn=get_discrete_x(poped.db$Gx,poped.db$discrete_x,poped.db$bUseGrouped_x)
+        xoptn=get_discrete_x(poped.db$design_space$G_x,poped.db$design_space$discrete_x,poped.db$design_space$bUseGrouped_x)
       }
       if((opta==TRUE)){
-        if((poped.db$bUseGrouped_a)){
-          aoptn=grouped_rand_a(poped.db$Ga,aopt,da,ff,aa)
+        if((poped.db$design_space$bUseGrouped_a)){
+          aoptn=grouped_rand_a(poped.db$design_space$G_a,aopt,da,ff,aa)
         } else {
-          aoptn=aopt+da/ff*randn(m,poped.db$na)*(aa>0)
+          aoptn=aopt+da/ff*randn(m,size(poped.db$design$a,2))*(aa>0)
         }
         aoptn=aoptn-((aoptn>maxa)*(aoptn-maxa))
         aoptn=aoptn+((aoptn<mina)*(mina-aoptn))
       }
-      designsin = update_designinlist(designsin,poped.db$groupsize,ni,xtoptn,xoptn,aoptn,-1,0)
+      designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xtoptn,xoptn,aoptn,-1,0)
     }
     
     stop("Parallel execution not yet implemented in PopED for R")
@@ -298,8 +298,8 @@ RS_opt <- function(poped.db,
       tic()
       for(it in 1:rsit){
         if((optxt==TRUE)){
-          if((poped.db$bUseGrouped_xt)){
-            xtoptn=grouped_rand(poped.db$G,xtopt,dxt,ff,axt)
+          if((poped.db$design_space$bUseGrouped_xt)){
+            xtoptn=grouped_rand(poped.db$design_space$G_xt,xtopt,dxt,ff,axt)
           } else {
             xtoptn=xtopt+dxt/ff*randn(m,maxni)*(axt>0)
           }
@@ -307,13 +307,13 @@ RS_opt <- function(poped.db,
           xtoptn=xtoptn+((xtoptn<minxt)*(minxt-xtoptn))
         }
         if((optx==TRUE)){
-          xoptn=get_discrete_x(poped.db$Gx,poped.db$discrete_x,poped.db$bUseGrouped_x)
+          xoptn=get_discrete_x(poped.db$design_space$G_x,poped.db$design_space$discrete_x,poped.db$design_space$bUseGrouped_x)
         }
         if((opta==TRUE)){
-          if((poped.db$bUseGrouped_a)){
-            aoptn=grouped_rand_a(poped.db$Ga,aopt,da,ff,aa)
+          if((poped.db$design_space$bUseGrouped_a)){
+            aoptn=grouped_rand_a(poped.db$design_space$G_a,aopt,da,ff,aa)
           } else {
-            aoptn=aopt+da/ff*randn(m,poped.db$na)*(aa>0)
+            aoptn=aopt+da/ff*randn(m,size(poped.db$design$a,2))*(aa>0)
           }
           aoptn=aoptn-((aoptn>maxa)*(aoptn-maxa))
           aoptn=aoptn+((aoptn<mina)*(mina-aoptn))
@@ -323,16 +323,16 @@ RS_opt <- function(poped.db,
                              bpop.val=bpop,
                              d_full=d,
                              docc_full=docc_full,
-                             sigma_full=poped.db$sigma,
+                             sigma_full=poped.db$parameters$sigma,
                              model_switch=model_switch,
                              ni=ni,
                              xt=xtoptn,
                              x=xoptn,
                              a=aoptn,
-                             groupsize=poped.db$groupsize,
+                             groupsize=poped.db$design$groupsize,
                              fim.calc.type=fim.calc.type,
                              ...)
-        #         returnArgs <- mftot(model_switch,poped.db$groupsize,ni,xtoptn,xoptn,aoptn,bpop,d,poped.db$sigma,docc_full,poped.db) 
+        #         returnArgs <- mftot(model_switch,poped.db$design$groupsize,ni,xtoptn,xoptn,aoptn,bpop,d,poped.db$parameters$sigma,docc_full,poped.db) 
         #         nfmf <- returnArgs[[1]]
         #         poped.db <- returnArgs[[2]]
         ndmf=ofv_fim(nfmf,poped.db,...)
@@ -353,13 +353,13 @@ RS_opt <- function(poped.db,
         } else {
           nullit=nullit+1
         }
-        if((nullit==poped.db$maxrsnullit) ){# when to make the search area smaller
+        if((nullit==poped.db$settings$maxrsnullit) ){# when to make the search area smaller
           ff=ff+1
           nullit=1
         }
         
-        if((!isempty(poped.db$strIterationFileName))){
-          write_iterationfile('Random Search',it,xtopt,aopt,xopt,ni,poped.db$groupsize,fmf,dmf,poped.db)
+        if((!isempty(poped.db$settings$strIterationFileName))){
+          write_iterationfile('Random Search',it,xtopt,aopt,xopt,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
         }
         
         if((trflag && (rem(it,rsit_output)==0 || trflag && it==rsit))){
@@ -378,13 +378,17 @@ RS_opt <- function(poped.db,
   # ----------------- RANDOM SEARCH ENDS HERE
   
   # all output should be passed here to poped.db not just these 3
-  poped.db$gxt = xtopt
-  poped.db$gx = xopt
-  poped.db$ga = aopt
+  #poped.db$gxt = xtopt
+  #poped.db$gx = xopt
+  #poped.db$ga = aopt
+  
+  poped.db$design$xt <- xtopt
+  poped.db$design$x <-xopt
+  poped.db$design$a <-aopt
   
   #--------- Write results
   if((trflag)){
-    blockfinal(fn,fmf,dmf,poped.db$groupsize,ni,xtopt,xopt,aopt,model_switch,bpopdescr,ddescr,poped.db$docc,poped.db$sigma,poped.db,
+    blockfinal(fn,fmf,dmf,poped.db$design$groupsize,ni,xtopt,xopt,aopt,model_switch,bpopdescr,ddescr,poped.db$parameters$docc,poped.db$parameters$sigma,poped.db,
                  opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,fmf_init=fmf_init,dmf_init=dmf_init,param_cvs_init=param_cvs_init)
     #close(fn)
   }
