@@ -27,17 +27,17 @@ ed_mftot <- function(model_switch,groupsize,ni,xtoptn,xoptn,aoptn,bpopdescr,ddes
   s=0
   s1=0
   
-  fim_list=cell(1,poped.db$ED_samp_size)
-  d_gen_list=cell(1,poped.db$ED_samp_size)
-  docc_gen_list=cell(1,poped.db$ED_samp_size)
+  fim_list=cell(1,poped.db$settings$ED_samp_size)
+  d_gen_list=cell(1,poped.db$settings$ED_samp_size)
+  docc_gen_list=cell(1,poped.db$settings$ED_samp_size)
   
   
-  bpop_gen  <-  pargen(bpopdescr,poped.db$user_distribution_pointer,
-                    poped.db$ED_samp_size,poped.db$bLHS,zeros(1,0),poped.db)
+  bpop_gen  <-  pargen(bpopdescr,poped.db$model$user_distribution_pointer,
+                    poped.db$settings$ED_samp_size,poped.db$settings$bLHS,zeros(1,0),poped.db)
   
-  for(ct in 1:poped.db$ED_samp_size){
-    d_gen = getfulld(pargen(ddescr,poped.db$user_distribution_pointer,1,poped.db$bLHS,ct,poped.db),covd)
-    docc_gen = getfulld(pargen(docc,poped.db$user_distribution_pointer,1,poped.db$bLHS,ct,poped.db),poped.db$covdocc)
+  for(ct in 1:poped.db$settings$ED_samp_size){
+    d_gen = getfulld(pargen(ddescr,poped.db$model$user_distribution_pointer,1,poped.db$settings$bLHS,ct,poped.db),covd)
+    docc_gen = getfulld(pargen(docc,poped.db$model$user_distribution_pointer,1,poped.db$settings$bLHS,ct,poped.db),poped.db$parameters$covdocc)
     returnArgs <- mftot(model_switch,groupsize,ni,xtoptn,xoptn,aoptn,bpop_gen[ct,],d_gen,sigma,docc_gen,poped.db) 
     mftmp <- returnArgs[[1]]
     poped.db <- returnArgs[[2]]
@@ -47,14 +47,14 @@ ed_mftot <- function(model_switch,groupsize,ni,xtoptn,xoptn,aoptn,bpopdescr,ddes
     d_gen_list[[ct]]=d_gen
     docc_gen_list[[ct]]=docc_gen
   }
-  if((!isempty(poped.db$ed_penalty_pointer))){
-    returnArgs <- feval(poped.db$ed_penalty_pointer,fim_list,bpop_gen,d_gen_list,docc_gen_list,model_switch,groupsize,ni,xtoptn,xoptn,aoptn,bpopdescr,ddescr,covd,sigma,docc,poped.db) 
+  if((!isempty(poped.db$settings$ed_penalty_pointer))){
+    returnArgs <- feval(poped.db$settings$ed_penalty_pointer,fim_list,bpop_gen,d_gen_list,docc_gen_list,model_switch,groupsize,ni,xtoptn,xoptn,aoptn,bpopdescr,ddescr,covd,sigma,docc,poped.db) 
     ED_fim <- returnArgs[[1]]
     ED_ofv <- returnArgs[[2]]
     poped.db <- returnArgs[[3]]
   } else {
-    ED_ofv=s/poped.db$ED_samp_size
-    ED_fim=s1/poped.db$ED_samp_size
+    ED_ofv=s/poped.db$settings$ED_samp_size
+    ED_fim=s1/poped.db$settings$ED_samp_size
   }
   return(list( ED_fim= ED_fim,ED_ofv=ED_ofv,poped.db=poped.db)) 
 }
