@@ -2,7 +2,7 @@
 #' 
 #' This is just a wrapper for the \code{\link{do.call}} function to behave like the feval function in MATLAB.
 #' 
-#' @param file.name A string that is either a function or a file name (with an .R extension). 
+#' @param file.name A function or a string that is the name of a function. 
 #' @param ... Arguments for the function.  Multiple arguments separated by a comma.
 #' 
 #' @return Output from the defined function.
@@ -14,6 +14,6 @@
 ## Author: Andrew Hooker
 
 feval <- function(file.name,...){
-    func.name <- gsub("\\.R$","",file.name)
-    do.call(func.name,list(...))
+    #func.name <- gsub("\\.R$","",file.name)
+    do.call(file.name,list(...))
 }
