@@ -22,38 +22,39 @@
 mf3 <- function(model_switch,xt,x,a,bpop,d,sigma,docc,poped.db){
   #Calculate the reduced FIM
   
-  numnotfixed_bpop = sum(poped.db$notfixed_bpop)
-  numnotfixed_d    = sum(poped.db$notfixed_d)
-  numnotfixed_covd = sum(poped.db$notfixed_covd)
-  numnotfixed_docc  = sum(poped.db$notfixed_docc)
-  numnotfixed_covdocc  = sum(poped.db$notfixed_covdocc)
-  numnotfixed_sigma  = sum(poped.db$notfixed_sigma)
-  numnotfixed_covsigma  = sum(poped.db$notfixed_covsigma)
+  numnotfixed_bpop = sum(poped.db$parameters$notfixed_bpop)
+  numnotfixed_d    = sum(poped.db$parameters$notfixed_d)
+  numnotfixed_covd = sum(poped.db$parameters$notfixed_covd)
+  numnotfixed_docc  = sum(poped.db$parameters$notfixed_docc)
+  numnotfixed_covdocc  = sum(poped.db$parameters$notfixed_covdocc)
+  numnotfixed_sigma  = sum(poped.db$parameters$notfixed_sigma)
+  numnotfixed_covsigma  = sum(poped.db$parameters$notfixed_covsigma)
   
   n=size(xt,1)
   ret = 0
   
-  for(i in 1:poped.db$iFOCENumInd){
-    b_ind = poped.db$b_global[,i,drop=F]
-    bocc_ind = poped.db$bocc_global[[i]]
+  for(i in 1:poped.db$settings$iFOCENumInd){
+    b_ind = poped.db$parameters$b_global[,i,drop=F]
+    bocc_ind = poped.db$parameters$bocc_global[[i]]
     
-    if((poped.db$bCalculateEBE) ){#Calculate an EBE
-      epsi0 = zeros(1,length(poped.db$notfixed_sigma))
-      g=feval(poped.db$fg_pointer,x,a,bpop,b_ind,bocc_ind)
-      returnArgs <- feval(poped.db$ferror_pointer,model_switch,xt,g,epsi0,poped.db) 
+    if((poped.db$settings$bCalculateEBE) ){#Calculate an EBE
+      epsi0 = zeros(1,length(poped.db$parameters$notfixed_sigma))
+      g=feval(poped.db$model$fg_pointer,x,a,bpop,b_ind,bocc_ind)
+      returnArgs <- feval(poped.db$model$ferror_pointer,model_switch,xt,g,epsi0,poped.db) 
       mean_data <- returnArgs[[1]]
       poped.db <- returnArgs[[2]]
       start_bind = t(b_ind)
-      b_ind = ind_estimates(mean_data,bpop,d,sigma,start_bind,(poped.db$iApproximationMethod==2),FALSE,model_switch,xt,x,a,b_ind,bocc_ind,poped.db)
-      #        b_ind2 = ind_estimates(mean_data,bpop,d,sigma,t(b_ind),(poped.db$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+      b_ind = ind_estimates(mean_data,bpop,d,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt,x,a,b_ind,bocc_ind,poped.db)
+      #        b_ind2 = ind_estimates(mean_data,bpop,d,sigma,t(b_ind),(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
       
-      #b_ind2 = ind_estimates(mean_data,bpop,d,sigma,t(zeros(size(b_ind)[1],size(b_ind)[2])),!(poped.db$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+      #b_ind2 = ind_estimates(mean_data,bpop,d,sigma,t(zeros(size(b_ind)[1],size(b_ind)[2])),!(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
       poped.db$mean_data = mean_data
     }
     
     
     f1=zeros(n+n*n,numnotfixed_bpop+numnotfixed_d+numnotfixed_covd+numnotfixed_docc+numnotfixed_covdocc+numnotfixed_sigma+numnotfixed_covsigma)
     returnArgs <- m1(model_switch,xt,x,a,bpop,b_ind,bocc_ind,d,poped.db) 
+    # if(numnotfixed_bpop==0) then redefine what to do
     f1[1:n,1:numnotfixed_bpop] <- returnArgs[[1]]
     poped.db <- returnArgs[[2]]
     returnArgs <- m3(model_switch,xt,x,a,bpop,b_ind,bocc_ind,d,sigma,docc,TRUE,poped.db) 
@@ -75,7 +76,7 @@ mf3 <- function(model_switch,xt,x,a,bpop,d,sigma,docc,poped.db){
       ret = ret+t(f1)%*%f2%*%f1
     }
   }
-  ret = ret/poped.db$iFOCENumInd
+  ret = ret/poped.db$settings$iFOCENumInd
   
   return(list( ret= ret,poped.db=poped.db)) 
 }
