@@ -26,20 +26,20 @@
 ## Author: Andrew Hooker
 
 mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,maxa,mina,fmf,dmf,
-                 EAStepSize=poped.db$EAStepSize,ourzero=poped.db$ourzero,
-                 opt_xt=poped.db$optsw[2],
-                 opt_a=poped.db$optsw[4],
-                 opt_x=poped.db$optsw[3],
-                 #opt_samps=poped.db$optsw[1],
-                 #opt_inds=poped.db$optsw[5],
+                 EAStepSize=poped.db$settings$EAStepSize,ourzero=poped.db$settings$ourzero,
+                 opt_xt=poped.db$settings$optsw[2],
+                 opt_a=poped.db$settings$optsw[4],
+                 opt_x=poped.db$settings$optsw[3],
+                 #opt_samps=poped.db$settings$optsw[1],
+                 #opt_inds=poped.db$settings$optsw[5],
                  trflag=T,
                  ...){
   
-  if((poped.db$EACriteria!=1)){
+  if((poped.db$settings$EACriteria!=1)){
     stop(sprintf('The criteria that can be used is Modified Fedorov Exchange Algorithm (EACriteria = 1)'))
   }
-  poped.db$parallelSettings$bParallelMFEA
-  if((poped.db$parallelSettings$bParallelMFEA == 1)){
+  poped.db$settings$parallel$bParallelMFEA
+  if((poped.db$settings$parallel$bParallelMFEA == 1)){
     designsin = cell(1,0) # temporary solution
     iParallelN = 2
   } else {
@@ -48,16 +48,16 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
   
   m=size(ni,1)
   
-  rho=poped.db$EAConvergenceCriteria
+  rho=poped.db$settings$EAConvergenceCriteria
   xt_current = xt
   a_current = a
   x_current = x
   bpop=bpopdescr[,2,drop=F]
-  d=getfulld(ddescr[,2,drop=F],poped.db$covd)
-  doccfull = getfulld(poped.db$docc[,2,drop=F],poped.db$covdocc)
+  d=getfulld(ddescr[,2,drop=F],poped.db$parameters$covd)
+  doccfull = getfulld(poped.db$parameters$docc[,2,drop=F],poped.db$parameters$covdocc)
   
   stepsize = EAStepSize
-  numpoints = poped.db$EANumPoints
+  numpoints = poped.db$settings$EANumPoints
   
   delta_max = rho+0.1
   it = 0
@@ -68,9 +68,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
   
   
   
-  # if((poped.db$bShowGraphs)){
+  # if((poped.db$settings$bShowGraphs)){
   #     cfg = figure(1)
-  #     if((poped.db$Engine$Type==1) ){#Matlab
+  #     if((poped.db$settings$Engine$Type==1) ){#Matlab
   #         set(cfg,'Name','Exchange Algorithm')
   #     }
   # }
@@ -79,17 +79,17 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
     dmfvector <- c()
     best_it = 0
     if((it==0)){
-      if((poped.db$d_switch)){
+      if((poped.db$settings$d_switch)){
         if((iParallelN==1)){ #IF NOT PARALLEL MFEA
-          returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_current,x_current,a_current,bpop,d,poped.db$sigma,doccfull,poped.db) 
+          returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_current,a_current,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
           nfmf <- returnArgs[[1]]
           poped.db <- returnArgs[[2]]
           optofv=ofv_fim(nfmf,poped.db)
         } else { ##STORE DESIGN FOR PARALLEL EXEC.
-          designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_current,x_current,a_current,-1,0)
+          designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_current,x_current,a_current,-1,0)
         }
       } else {
-        returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_current,x_current,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+        returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_current,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
         nfmf <- returnArgs[[1]]
         optofv <- returnArgs[[2]]
         poped.db <- returnArgs[[3]]
@@ -110,9 +110,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                        opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,
                        opt_inds=F,opt_samps=F,
                        fmf=nfmf,dmf=optofv,
-                       bpop=bpopdescr,d=ddescr,docc=poped.db$docc,sigma=poped.db$sigma,trflag=trflag,...)
+                       bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,trflag=trflag,...)
       #       param_vars_init=diag_matlab(inv(nfmf))
-      #       returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$docc,sigma=poped.db$sigma,poped.db) 
+      #       returnArgs <-  get_cv(param_vars_init,bpop=bpopdescr,d=ddescr,docc=poped.db$parameters$docc,sigma=poped.db$parameters$sigma,poped.db) 
       #       params_init <- returnArgs[[1]]
       #       param_cvs_init <- returnArgs[[2]]
     }
@@ -142,12 +142,12 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
             }
           }
           
-          if((poped.db$bUseGrouped_xt)){
+          if((poped.db$design_space$bUseGrouped_xt)){
             if((bFirstInGroup_xt)){
               bFirstInGroup_xt = FALSE
-              for(k in 1:max(max(poped.db$G))){
+              for(k in 1:max(max(poped.db$design_space$G_xt))){
                 tmp = matrix(1,size(xt,1),size(xt,2))*k
-                inters = (poped.db$G==tmp)
+                inters = (poped.db$design_space$G_xt==tmp)
                 if((sum(sum(inters))!=0) ){#If we have a sample defined here (accord. to G)
                   returnArgs <-  which(inters,arr.ind=T) 
                   col <- returnArgs[,"col"]
@@ -169,7 +169,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                       tt[tt==0]=ourzero
                     }
                     
-                    if(poped.db$bEANoReplicates){
+                    if(poped.db$settings$bEANoReplicates){
                       #remove already taken points
                       tt=setdiff(tt,unique(xt_current[unique(col),,drop=F]))
                     }
@@ -179,15 +179,15 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                       ti = tt[j]
                       xt_tmp = xt_current*(inters==0)+ti*(inters!=0)
                       
-                      if((poped.db$d_switch)){
+                      if((poped.db$settings$d_switch)){
                         if((iParallelN==1)){
-                          returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                          returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                           nfmf <- returnArgs[[1]]
                           poped.db <- returnArgs[[2]]
                           nofv=ofv_fim(nfmf,poped.db)
                         } else {
                           if((p==1)){
-                            designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_tmp,x_current,a_current,-1,0)
+                            designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,-1,0)
                           } else {
                             nfmf = designout[[des_num]]$FIM
                             nofv = designout[[des_num]]$ofv
@@ -195,7 +195,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           }
                         }
                       } else {
-                        returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                        returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                         nfmf <- returnArgs[[1]]
                         nofv <- returnArgs[[2]]
                         poped.db <- returnArgs[[3]]
@@ -212,9 +212,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           best_it = best_it + 1
                           dmfvector[best_it]=dmf
                           fmf = nfmf
-                          graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_tmp,a_current,x_current,ni,m,dmfvector,best_it,poped.db$Engine)
-                          if((!isempty(poped.db$strIterationFileName))){
-                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_tmp,a_current,x_current,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                          graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_tmp,a_current,x_current,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                          if((!isempty(poped.db$settings$strIterationFileName))){
+                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_tmp,a_current,x_current,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                           }
                         }
                       }
@@ -245,15 +245,15 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                     ti = tt[j]
                     xt_tmp[i,ct] = ti
                     
-                    if((poped.db$d_switch)){
+                    if((poped.db$settings$d_switch)){
                       if((iParallelN==1)){
-                        returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                        returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                         nfmf <- returnArgs[[1]]
                         poped.db <- returnArgs[[2]]
                         nofv=ofv_fim(nfmf,poped.db)
                       } else {
                         if((p==1)){
-                          designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_tmp,x_current,a_current,-1,0)
+                          designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,-1,0)
                         } else {
                           
                           nfmf = designout[[des_num]]$FIM
@@ -262,7 +262,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         }
                       }
                     } else {
-                      returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                      returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                       nfmf <- returnArgs[[1]]
                       nofv <- returnArgs[[2]]
                       poped.db <- returnArgs[[3]]
@@ -280,9 +280,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         fmf = nfmf
                         best_it = best_it+1
                         dmfvector[best_it]=dmf
-                        graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_tmp,a_current,x_current,ni,m,dmfvector,best_it,poped.db$Engine)
-                        if((!isempty(poped.db$strIterationFileName))){
-                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_tmp,a_current,x_current,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                        graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_tmp,a_current,x_current,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                        if((!isempty(poped.db$settings$strIterationFileName))){
+                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_tmp,a_current,x_current,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                         }
                       }
                       xt_tmp[i,ct] = xt_current[i,ct]
@@ -315,29 +315,29 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
             }
           }
           
-          if((poped.db$bUseGrouped_x)){
+          if((poped.db$design_space$bUseGrouped_x)){
             if((bFirstInGroup_x)){
               bFirstInGroup_x = FALSE
-              for(k in 1:max(max(poped.db$Gx))){
+              for(k in 1:max(max(poped.db$design_space$G_x))){
                 tmp = matrix(1,size(x,1),size(x,2))*k
-                inters = (poped.db$Gx==tmp)
+                inters = (poped.db$design_space$G_x==tmp)
                 if((sum(sum(inters))!=0) ){#If we have a discrete variabel defined here (accord. to Gx)
-                  tt=get_discrete_val(inters,poped.db$discrete_x)
+                  tt=get_discrete_val(inters,poped.db$design_space$discrete_x)
                   if((length(tt)>1)){
                     ntt = length(tt)
                     for(j in 1:ntt){
                       ti = tt[j]
                       x_tmp = x_current*(inters==0)+ti*(inters!=0)
                       
-                      if((poped.db$d_switch)){
+                      if((poped.db$settings$d_switch)){
                         if((iParallelN==1)){
-                          returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_current,x_tmp,a_current,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                          returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                           nfmf <- returnArgs[[1]]
                           poped.db <- returnArgs[[2]]
                           nofv=ofv_fim(nfmf,poped.db)
                         } else { #PARALLEL DESIGN STORAGE
                           if((p==1)){
-                            designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_current,x_tmp,a_current,-1,0)
+                            designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,-1,0)
                           } else {
                             nfmf = designout[[des_num]]$FIM
                             nofv = designout[[des_num]]$ofv
@@ -345,7 +345,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           }
                         }
                       } else {
-                        returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_current,x_tmp,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                        returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                         nfmf <- returnArgs[[1]]
                         nofv <- returnArgs[[2]]
                         poped.db <- returnArgs[[3]]
@@ -362,9 +362,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           best_it = best_it+1
                           dmfvector[best_it]=dmf
                           fmf = nfmf
-                          graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_current,a_current,x_tmp,ni,m,dmfvector,best_it,poped.db$Engine)
-                          if((!isempty(poped.db$strIterationFileName))){
-                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_current,x_tmp,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                          graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_current,a_current,x_tmp,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                          if((!isempty(poped.db$settings$strIterationFileName))){
+                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_current,x_tmp,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                           }
                         }
                       }
@@ -376,7 +376,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
           } else {
             for(ct in 1:length(x[i,]) ){#For all discrete variables in group
               if((previous_type!=3 || previous_index_i!=i || previous_index_ct!=ct)){
-                discrete_val = poped.db$discrete_x[[i,ct]]
+                discrete_val = poped.db$design_space$discrete_x[[i,ct]]
                 if((length(discrete_val)>1)){
                   ntt = length(discrete_val)
                   x_tmp = x_current
@@ -384,15 +384,15 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                     ti = discrete_val[j]
                     x_tmp[i,ct] = ti
                     
-                    if((poped.db$d_switch)){
+                    if((poped.db$settings$d_switch)){
                       if((iParallelN==1)){
-                        returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_current,x_tmp,a_current,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                        returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                         nfmf <- returnArgs[[1]]
                         poped.db <- returnArgs[[2]]
                         nofv=ofv_fim(nfmf,poped.db)
                       } else { #PARALLEL DESIGN STORAGE
                         if((p==1)){
-                          designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_current,x_tmp,a_current,-1,0)
+                          designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,-1,0)
                         } else {
                           nfmf = designout[[des_num]]$FIM
                           nofv = designout[[des_num]]$ofv
@@ -400,7 +400,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         }
                       }
                     } else {
-                      returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_current,x_tmp,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                      returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_tmp,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                       nfmf <- returnArgs[[1]]
                       nofv <- returnArgs[[2]]
                       poped.db <- returnArgs[[3]]
@@ -418,9 +418,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         best_it = best_it+1
                         dmfvector[best_it]=dmf
                         fmf = nfmf
-                        graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_current,a_current,x_tmp,ni,m,dmfvector,best_it,poped.db$Engine)
-                        if((!isempty(poped.db$strIterationFileName))){
-                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_current,x_tmp,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                        graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_current,a_current,x_tmp,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                        if((!isempty(poped.db$settings$strIterationFileName))){
+                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_current,x_tmp,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                         }
                       }
                     }
@@ -451,12 +451,12 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
               }
             }
           }
-          if((poped.db$bUseGrouped_a)){
+          if((poped.db$design_space$bUseGrouped_a)){
             if((bFirstInGroup_a)){
               bFirstInGroup_a = FALSE
-              for(k in 1:max(max(poped.db$Ga))){
+              for(k in 1:max(max(poped.db$design_space$G_a))){
                 tmp = matrix(1,size(a,1),size(a,2))*k
-                inters = (poped.db$Ga==tmp)
+                inters = (poped.db$design_space$G_a==tmp)
                 if((sum(sum(inters))!=0) ){#If we have a covariate defined here (accord. to Ga)
                   returnArgs <-  find(inters) 
                   col <- returnArgs[[1]]
@@ -474,15 +474,15 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                       ti = tt[j]
                       a_tmp = a_current*(inters==0)+ti*(inters!=0)
                       
-                      if((poped.db$d_switch)){
+                      if((poped.db$settings$d_switch)){
                         if((iParallelN==1)){
-                          returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_current,x_current,a_tmp,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                          returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_current,a_tmp,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                           nfmf <- returnArgs[[1]]
                           poped.db <- returnArgs[[2]]
                           nofv=ofv_fim(nfmf,poped.db)
                         } else { #PARALLEL DESIGN STORAGE
                           if((p==1)){
-                            designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_current,x_current,a_tmp,-1,0)
+                            designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_current,x_current,a_tmp,-1,0)
                           } else {
                             nfmf = designout[[des_num]]$FIM
                             nofv = designout[[des_num]]$ofv
@@ -490,7 +490,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           }
                         }
                       } else {
-                        returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                        returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                         nfmf <- returnArgs[[1]]
                         nofv <- returnArgs[[2]]
                         poped.db <- returnArgs[[3]]
@@ -506,9 +506,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                           best_it = best_it+1
                           dmfvector[best_it]=dmf
                           fmf = nfmf
-                          graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_current,a_tmp,x_current,ni,m,dmfvector,best_it,poped.db$Engine)
-                          if((!isempty(poped.db$strIterationFileName))){
-                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_tmp,x_current,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                          graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_current,a_tmp,x_current,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                          if((!isempty(poped.db$settings$strIterationFileName))){
+                            write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_tmp,x_current,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                           }
                         }
                       }
@@ -532,15 +532,15 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                     ti = tt[j]
                     a_tmp[i,ct] = ti
                     
-                    if((poped.db$d_switch)){
+                    if((poped.db$settings$d_switch)){
                       if((iParallelN==1)){
-                        returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_current,x_current,a_tmp,bpop,d,poped.db$sigma,doccfull,poped.db) 
+                        returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_current,x_current,a_tmp,bpop,d,poped.db$parameters$sigma,doccfull,poped.db) 
                         nfmf <- returnArgs[[1]]
                         poped.db <- returnArgs[[2]]
                         nofv=ofv_fim(nfmf,poped.db)
                       } else { #PARALLEL DESIGN STORAGE
                         if((p==1)){
-                          designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_current,x_current,a_tmp,-1,0)
+                          designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_current,x_current,a_tmp,-1,0)
                         } else {
                           nfmf = designout[[des_num]]$FIM
                           nofv = designout[[des_num]]$ofv
@@ -548,7 +548,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         }
                       }
                     } else {
-                      returnArgs <-  ed_mftot(model_switch,poped.db$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$covd,poped.db$sigma,poped.db$docc,poped.db) 
+                      returnArgs <-  ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_tmp,x_current,a_current,bpopdescr,ddescr,poped.db$parameters$covd,poped.db$parameters$sigma,poped.db$parameters$docc,poped.db) 
                       nfmf <- returnArgs[[1]]
                       nofv <- returnArgs[[2]]
                       poped.db <- returnArgs[[3]]
@@ -565,9 +565,9 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
                         best_it = best_it+1
                         dmfvector[best_it]=dmf
                         fmf = nfmf
-                        graph_det(poped.db$bShowGraphs,poped.db$optsw,xt_current,a_tmp,x_current,ni,m,dmfvector,best_it,poped.db$Engine)
-                        if((!isempty(poped.db$strIterationFileName))){
-                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_tmp,x_current,ni,poped.db$groupsize,fmf,dmf,poped.db)
+                        graph_det(poped.db$settings$bShowGraphs,poped.db$settings$optsw,xt_current,a_tmp,x_current,ni,m,dmfvector,best_it,poped.db$settings$Engine)
+                        if((!isempty(poped.db$settings$strIterationFileName))){
+                          write_iterationfile('Modified Exchange Algorithm',best_it,xt_current,a_tmp,x_current,ni,poped.db$design$groupsize,fmf,dmf,poped.db)
                         }
                       }
                     }
@@ -592,21 +592,21 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
       previous_type = type
       
       if((type==1)){
-        if((!poped.db$bUseGrouped_xt)){
+        if((!poped.db$design_space$bUseGrouped_xt)){
           fprintf('Exchanged sample %d in group/ind %d from %g to %g\n',ct_index,i_index,xt_current[i_index,ct_index],t_max)
           if(trflag) fprintf(fn,'Exchanged sample %d in group/ind %d from %g to %g\n',ct_index,i_index,xt_current[i_index,ct_index],t_max)         
           previous_index_ct = ct_index
           xt_current[i_index,ct_index] = t_max
         } else {
           tmp = matrix(1,size(xt,1),size(xt,2))*i_index
-          inters = (poped.db$G==tmp)
-          fprintf('Exchanged a grouped sample (grouped as %d) from %g to %g\n',i_index,max(max(xt_current[poped.db$G==tmp])),t_max)
-          if(trflag) fprintf(fn,'Exchanged a grouped sample (grouped as %d) from %g to %g\n',i_index,max(max(xt_current[poped.db$G==tmp])),t_max)             
+          inters = (poped.db$design_space$G_xt==tmp)
+          fprintf('Exchanged a grouped sample (grouped as %d) from %g to %g\n',i_index,max(max(xt_current[poped.db$design_space$G_xt==tmp])),t_max)
+          if(trflag) fprintf(fn,'Exchanged a grouped sample (grouped as %d) from %g to %g\n',i_index,max(max(xt_current[poped.db$design_space$G_xt==tmp])),t_max)             
           xt_current=xt_current*(inters==0)+t_max*(inters!=0)
         }
       } else {
         if((type==2)){
-          if((!poped.db$bUseGrouped_a)){
+          if((!poped.db$design_space$bUseGrouped_a)){
             fprintf('Exchanged covariate %d in group/ind %d from %g to %g\n',ct_index,i_index,a_current[i_index,ct_index],t_max)
             if(trflag) fprintf(fn,'Exchanged covariate %d in group/ind %d from %g to %g\n',ct_index,i_index,a_current[i_index,ct_index],t_max)         
             previous_index_ct = ct_index
@@ -615,12 +615,12 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
             fprintf('Exchanged a grouped covariate (grouped as %d) to %g\n',i_index,t_max)
             if(trflag) fprintf(fn,'Exchanged a grouped covariate (grouped as %d) to %g\n',i_index,t_max)
             tmp = matrix(1,size(a,1),size(a,2))*i_index
-            inters = (poped.db$Ga==tmp)
+            inters = (poped.db$design_space$G_a==tmp)
             a_current=a_current*(inters==0)+t_max*(inters!=0)
           }
         } else {
           if((type==3)){
-            if((!poped.db$bUseGrouped_x)){
+            if((!poped.db$design_space$bUseGrouped_x)){
               fprintf('Exchanged discrete variable %d in group/ind %d from %g to %g\n',ct_index,i_index,x_current[i_index,ct_index],t_max)
               if(trflag) fprintf(fn,'Exchanged discrete variable %d in group/ind %d from %g to %g\n',ct_index,i_index,x_current[i_index,ct_index],t_max)
               previous_index_ct = ct_index
@@ -629,7 +629,7 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
               fprintf('Exchanged a grouped discrete variable (grouped as %d) to %g\n',i_index,t_max)
               if(trflag) fprintf(fn,'Exchanged a grouped discrete variable (grouped as %d) to %g\n',i_index,t_max)              
               tmp = matrix(1,size(x,1),size(x,2))*i_index
-              inters = (poped.db$Gx==tmp)
+              inters = (poped.db$design_space$G_x==tmp)
               x_current=x_current*(inters==0)+t_max*(inters!=0)
             }
           }
@@ -648,15 +648,22 @@ mfea <- function(poped.db,model_switch,ni,xt,x,a,bpopdescr,ddescr,maxxt,minxt,ma
   #--------- Write results
   #if((trflag)){
   #fprintf(fn,"\n")
-  blockfinal(fn,fmf,dmf,poped.db$groupsize,ni,xt,x,a,model_switch,bpopdescr,ddescr,
-               poped.db$docc,poped.db$sigma,poped.db,
+  blockfinal(fn,fmf,dmf,poped.db$design$groupsize,ni,xt,x,a,model_switch,bpopdescr,ddescr,
+               poped.db$parameters$docc,poped.db$parameters$sigma,poped.db,
                opt_xt=opt_xt,opt_a=opt_a,opt_x=opt_x,fmf_init=fmf_init,dmf_init=dmf_init,
                trflag=trflag,
                ...)
   #close(fn)
   #}
-  #blockfinal(fn,fmf,dmf,poped.db$groupsize,ni,xt,x,a,bpopdescr,ddescr,poped.db$docc,poped.db$sigma,m,poped.db)
+  #blockfinal(fn,fmf,dmf,poped.db$design$groupsize,ni,xt,x,a,bpopdescr,ddescr,poped.db$parameters$docc,poped.db$parameters$sigma,m,poped.db)
   
+  #poped.db$gxt = xt
+  #poped.db$design$x = x
+  #poped.db$design$a = a
+  
+  poped.db$design$xt <- xt
+  poped.db$design$x <-x
+  poped.db$design$a <-a
   
   return(list( xt= xt,x=x,a=a,fmf=fmf,dmf=dmf,poped.db=poped.db)) 
 }
