@@ -235,7 +235,7 @@ ff.PKPD.1.comp.oral.md.CL.imax <- function(model_switch,xt,parameters,poped.db){
 feps.add.prop <- function(model_switch,xt,parameters,epsi,poped.db){
   ## -- Residual Error function
   ## -- Additive + Proportional 
-  returnArgs <- do.call(poped.db$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
+  returnArgs <- do.call(poped.db$model$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
   y <- returnArgs[[1]]
   poped.db <- returnArgs[[2]]
   y = y*(1+epsi[,1])+epsi[,2]
@@ -268,7 +268,7 @@ feps.add.prop <- function(model_switch,xt,parameters,epsi,poped.db){
 feps.add <- function(model_switch,xt,parameters,epsi,poped.db){
   ## -- Residual Error function
   ## -- Additive 
-  returnArgs <- do.call(poped.db$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
+  returnArgs <- do.call(poped.db$model$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
   y <- returnArgs[[1]]
   poped.db <- returnArgs[[2]]
   y = y+epsi[,1]
@@ -302,7 +302,7 @@ feps.add <- function(model_switch,xt,parameters,epsi,poped.db){
 feps.prop <- function(model_switch,xt,parameters,epsi,poped.db){
   ## -- Residual Error function
   ## -- Proportional 
-  returnArgs <- do.call(poped.db$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
+  returnArgs <- do.call(poped.db$model$ff_pointer,list(model_switch,xt,parameters,poped.db)) 
   y <- returnArgs[[1]]
   poped.db <- returnArgs[[2]]
   y = y*(1+epsi[,1])
