@@ -2,7 +2,7 @@
 #' 
 #' Function plots the efficiency of windows around the optimal design points.  The maximal and minimal allowed values for all
 #' design variables as defined in 
-#' poped.db are respected (e.g. poped.db$design$minxt and poped.db$design$maxxt).
+#' poped.db are respected (e.g. poped.db$design_space$minxt and poped.db$design_space$maxxt).
 #' 
 #' @param poped.db A poped database
 #' @param iNumSimulations The number of design simulations to make within the specified windows.
@@ -10,11 +10,11 @@
 #' @inheritParams create.poped.database
 #' @param ... Extra arguments passed to \code{evaluate.fim}
 #' @param xt_windows The distance on one direction from the optimal sample times.  Can be a number or a matrix of the same size as 
-#' the xt matrix found in \code{poped.db$gxt}. 
+#' the xt matrix found in \code{poped.db$design$xt}. 
 #' @param xt_plus The upper distance from the optimal sample times (xt + xt_plus). Can be a number or a matrix of the same size as 
-#' the xt matrix found in \code{poped.db$gxt}.
+#' the xt matrix found in \code{poped.db$design$xt}.
 #' @param xt_minus The lower distance from the optimal sample times (xt - xt_minus). Can be a number or a matrix of the same size as 
-#' the xt matrix found in \code{poped.db$gxt}.
+#' the xt matrix found in \code{poped.db$design$xt}.
 #' @param y_eff Should one of the plots created have efficiency on the y-axis?
 #' @param y_rse Should created plots include the relative standard error of each parameter as a value on the y-axis?   
 #' 
@@ -36,14 +36,15 @@ plot_efficiency_of_windows <- function(poped.db,
                                        y_eff = T,
                                        y_rse = T,
                                        #a_windows=NULL,x_windows=NULL,
-                                       #d_switch=poped.db$d_switch,
+                                       #d_switch=poped.db$settings$d_switch,
                                        ...){
   
   
   design = poped.db$design
-  design$xt <- poped.db$gxt
-  design$x <- poped.db$gx
-  design$a <- poped.db$ga
+  design_space = poped.db$design_space
+  #design$xt <- poped.db$gxt
+  #design$x <- poped.db$gx
+  #design$a <- poped.db$design$a
   
   p = get_fim_size(poped.db) #%Size of FIM
   
@@ -67,20 +68,20 @@ plot_efficiency_of_windows <- function(poped.db,
     xt_val_max <- xt_val
     if(!is.null(xt_minus)) xt_val_min <- xt_val - xt_minus
     if(!is.null(xt_plus)) xt_val_max <- xt_val + xt_plus
-    xt_val_min[xt_val_min<design$minxt] = design$minxt[xt_val_min<design$minxt]
-    xt_val_max[xt_val_max>design$maxxt] = design$maxxt[xt_val_max>design$maxxt]
+    xt_val_min[xt_val_min<design_space$minxt] = design_space$minxt[xt_val_min<design_space$minxt]
+    xt_val_max[xt_val_max>design_space$maxxt] = design_space$maxxt[xt_val_max>design_space$maxxt]
   }  
   
   for(i in 1:iNumSimulations){
     if(!is.null(xt_windows) || !is.null(xt_minus) || !is.null(xt_plus)){
       xt_new <- rand(size(xt_val,1),size(xt_val,2))*abs(xt_val_max - xt_val_min)+xt_val_min
-      if((poped.db$bUseGrouped_xt)){
+      if((poped.db$design_space$bUseGrouped_xt)){
         for(j in 1:size(xt_val,1) ){
-          for(k in min(poped.db$G[j,]):max(poped.db$G[j,])){
-            tmp.lst <- xt_new[j,poped.db$G[j,]==k]
+          for(k in min(poped.db$design_space$G_xt[j,]):max(poped.db$design_space$G_xt[j,])){
+            tmp.lst <- xt_new[j,poped.db$design_space$G_xt[j,]==k]
             if(length(tmp.lst)!=1){
               tmp <- sample(tmp.lst,1)
-              xt_new[j,poped.db$G[j,]==k]=tmp
+              xt_new[j,poped.db$design_space$G_xt[j,]==k]=tmp
             }
           }
         }
@@ -103,20 +104,20 @@ plot_efficiency_of_windows <- function(poped.db,
     #       }
     #     }
     
-    #     if((poped.db$bUseGrouped_xt)){
-    #       xt_val=group_matrix(xt_val,poped.db$G)
+    #     if((poped.db$design_space$bUseGrouped_xt)){
+    #       xt_val=group_matrix(xt_val,poped.db$design_space$G_xt)
     #     }
-    #     if((poped.db$bUseGrouped_a)){
-    #       a_val=group_matrix(a_val,poped.db$Ga)
+    #     if((poped.db$design_space$bUseGrouped_a)){
+    #       a_val=group_matrix(a_val,poped.db$design_space$G_a)
     #     }
-    #     if((poped.db$bUseGrouped_x)){
-    #       x_val=group_matrix(x_val,poped.db$Gx)
+    #     if((poped.db$design_space$bUseGrouped_x)){
+    #       x_val=group_matrix(x_val,poped.db$design_space$G_x)
     #     }
     #     
     #     if((!bParallel)){
-    #if((poped.db$d_switch)){
+    #if((poped.db$settings$d_switch)){
     fmf <- evaluate.fim(poped.db,xt=xt_val,...)
-    #       returnArgs <-  mftot(model_switch,poped.db$groupsize,ni,xt_val,x_val,a_val,bpop[,2],fulld,design$sigma,fulldocc,poped.db) 
+    #       returnArgs <-  mftot(model_switch,poped.db$design$groupsize,ni,xt_val,x_val,a_val,bpop[,2],fulld,design$sigma,fulldocc,poped.db) 
     #       fmf <- returnArgs[[1]]
     #       poped.db <- returnArgs[[2]]
     if(y_eff) eff[1,i] = ofv_criterion(ofv_fim(fmf,poped.db),p,poped.db)/ofv_criterion(ofv_fim(ref_fmf,poped.db),p,poped.db)
@@ -129,7 +130,7 @@ plot_efficiency_of_windows <- function(poped.db,
     #         eff(i) = (ofv_fim(fmf,poped.db)/optdetfim)
     #       }
     #     } else {
-    #       returnArgs <- ed_mftot(model_switch,poped.db$groupsize,ni,xt_val,x_val,a_val,bpop,d,poped.db$covd,design$sigma,poped.db$docc,poped.db) 
+    #       returnArgs <- ed_mftot(model_switch,poped.db$design$groupsize,ni,xt_val,x_val,a_val,bpop,d,poped.db$parameters$covd,design$sigma,poped.db$parameters$docc,poped.db) 
     #       fmf <- returnArgs[[1]]
     #       ED_det <- returnArgs[[2]]
     #       poped.db <- returnArgs[[3]]
@@ -149,7 +150,7 @@ plot_efficiency_of_windows <- function(poped.db,
     #             fileData(i,1+length(tmp_a)+length(tmp_xt):length(tmp_xt)+length(tmp_a)+length(tmp_x)) = tmp_x
     #             try
     #                 imf = inv(fmf)
-    #                  returnArgs <- get_cv(diag_matlab(imf),bpop,d,poped.db$docc,design$sigma,poped.db) 
+    #                  returnArgs <- get_cv(diag_matlab(imf),bpop,d,poped.db$parameters$docc,design$sigma,poped.db) 
     # params <- returnArgs[[1]]
     #  params_cv <- returnArgs[[2]]
     #             catch
@@ -159,7 +160,7 @@ plot_efficiency_of_windows <- function(poped.db,
     #             fileData(i,NumRows) = eff(i)
     #         }
     #     } else {
-    #          designsin = update_designinlist(designsin,poped.db$groupsize,ni,xt_val,x_val,a_val,i,0)
+    #          designsin = update_designinlist(designsin,poped.db$design$groupsize,ni,xt_val,x_val,a_val,i,0)
     #     }
     # }
     # 
@@ -184,7 +185,7 @@ plot_efficiency_of_windows <- function(poped.db,
     #         fileData(i,1+length(tmp_a)+length(tmp_xt):length(tmp_xt)+length(tmp_a)+length(tmp_x)) = tmp_x
     #         try
     #         imf = inv(fmf)
-    #         returnArgs <- get_cv(diag_matlab(imf),bpop,d,poped.db$docc,design$sigma,poped.db) 
+    #         returnArgs <- get_cv(diag_matlab(imf),bpop,d,poped.db$parameters$docc,design$sigma,poped.db) 
     #         params <- returnArgs[[1]]
     #         params_cv <- returnArgs[[2]]
     #         catch
@@ -236,12 +237,13 @@ plot_efficiency_of_windows <- function(poped.db,
     names(rse_df) <- colnames(rse)
     df <- cbind(df,rse_df)
   }
-  #parameter_names_ff <- codetools::findGlobals(eval(parse(text=poped.db$ff_pointer)),merge=F)$variables 
+  #parameter_names_ff <- codetools::findGlobals(eval(parse(text=poped.db$model$ff_pointer)),merge=F)$variables 
   df_stack <- cbind(df$sample,stack(df,select=-sample))
   names(df_stack) <- c("sample","values","ind")
   if(y_eff){
     levs <- levels(df_stack$ind)
-    levels(df_stack$ind) <- c("Efficiency",levs[-c(grep("Efficiency",levs))])
+    df_stack$ind <- factor(df_stack$ind,levels=c("Efficiency",levs[-c(grep("Efficiency",levs))]))
+    #levels(df_stack$ind) <- c("Efficiency",levs[-c(grep("Efficiency",levs))])
   }
   p <- ggplot(data=df_stack,aes(x=sample,y=values, group=ind))
   p <- p+geom_line()+geom_point() + facet_wrap(~ind,scales="free")
