@@ -4,14 +4,14 @@
 ind=1
 
 # no occasion defined in this example, so result is zero
-output <- mf6(model_switch=t(poped.db$global_model_switch[ind,,drop=FALSE]),
-   xt=t(poped.db$gxt[ind,,drop=FALSE]),
+output <- mf6(model_switch=t(poped.db$design$model_switch[ind,,drop=FALSE]),
+   xt=t(poped.db$design$xt[ind,,drop=FALSE]),
    x=zeros(0,1),
-   a=t(poped.db$ga[ind,,drop=FALSE]),
-   bpop=poped.db$gbpop[,2,drop=FALSE],
-   d=poped.db$param.pt.val$d,
-   sigma=poped.db$sigma,
-   docc=poped.db$param.pt.val$docc,
+   a=t(poped.db$design$a[ind,,drop=FALSE]),
+   bpop=poped.db$parameters$bpop[,2,drop=FALSE],
+   d=poped.db$parameters$param.pt.val$d,
+   sigma=poped.db$parameters$sigma,
+   docc=poped.db$parameters$param.pt.val$docc,
    poped.db)
 
 # in this simple case the full FIM is just the sum of the individual FIMs
